<section>
    <iframe src="{% url 'mail_save:email_alternative' pk %}"
            frameborder="0" allowtransparency="true"
            style="width:100%;min-height:500px;border:1px solid #eee;"></iframe>
</section>

